Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(341)

Unified Diff: sdk/lib/_internal/dartdoc/bin/dartdoc.dart

Issue 11293062: CL2: Update paths to reflect new lib structure. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/dartdoc/bin/dartdoc.dart
===================================================================
--- sdk/lib/_internal/dartdoc/bin/dartdoc.dart (revision 14473)
+++ sdk/lib/_internal/dartdoc/bin/dartdoc.dart (working copy)
@@ -20,10 +20,10 @@
// TODO(rnystrom): Use "package:" URL (#4968).
import '../lib/dartdoc.dart';
-import '../../args/lib/args.dart';
+import '../../../../../pkg/args/lib/args.dart';
/**
* Run this from the `pkg/dartdoc` directory.
*/
main() {
// Need this because ArgParser.getUsage doesn't show command invocation.
@@ -35,8 +35,8 @@
final argParser = new ArgParser();
- final Path libPath = scriptDir.append('../../../');
- Path pkgPath = scriptDir.append('../../../pkg/');
+ final Path libPath = scriptDir.append('../../../../');
+ Path pkgPath = scriptDir.append('../../../../pkg/');
argParser.addFlag('no-code',
help: 'Do not include source code in the documentation.',
@@ -166,7 +166,7 @@
}
});
- dartdoc.dartdocPath = libPath.append('pkg/dartdoc');
+ dartdoc.dartdocPath = libPath.append('lib/_internal/dartdoc');
if (args.isEmpty) {
print('No arguments provided.');
« no previous file with comments | « sdk/lib/_internal/compiler/samples/leap/leap_server.dart ('k') | sdk/lib/_internal/dartdoc/lib/classify.dart » ('j') | no next file with comments »
@@ -20,10 +20,10 @@
/**
- * Run this from the `pkg/dartdoc` directory.
+ * Run this from the `lib/_internal/dartdoc` directory.
*/
main() {

Powered by Google App Engine
This is Rietveld 408576698